==> pyconnectwise-0.5.0.tar.gz: pyconnectwise-0.5.0/src/pyconnectwise/endpoints/manage/CompanyCompaniesIdManagementsummaryreportsEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.CompanyCompaniesIdManagementsummaryreportsCountEndpoint import \
    CompanyCompaniesIdManagementsummaryreportsCountEndpoint
from pyconnectwise.endpoints.manage.CompanyCompaniesIdManagementsummaryreportsIdEndpoint import \
    CompanyCompaniesIdManagementsummaryreportsIdEndpoint
from pyconnectwise.interfaces import IDeleteable, IGettable, IPaginateable, IPatchable, IPostable, IPuttable
from pyconnectwise.models.manage import CompanyManagementSummary
from pyconnectwise.responses.paginated_response import PaginatedResponse
from pyconnectwise.types import JSON, ConnectWiseAutomateRequestParams, ConnectWiseManageRequestParams, PatchRequestData


class CompanyCompaniesIdManagementsummaryreportsEndpoint(
    ConnectWiseEndpoint,
    IGettable[list[CompanyManagementSummary], ConnectWiseManageRequestParams],
    IPostable[CompanyManagementSummary, ConnectWiseManageRequestParams],
    IPaginateable[CompanyManagementSummary, ConnectWiseManageRequestParams],
):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "managementSummaryReports", parent_endpoint=parent_endpoint)

        self.count = self._register_child_endpoint(
            CompanyCompaniesIdManagementsummaryreportsCountEndpoint(client, parent_endpoint=self)
        )

    def id(self, id: int) -> CompanyCompaniesIdManagementsummaryreportsIdEndpoint:
        """
        Sets the ID for this endpoint and returns an initialized CompanyCompaniesIdManagementsummaryreportsIdEndpoint object to move down the chain.

        Parameters:
            id (int): The ID to set.
        Returns:
            CompanyCompaniesIdManagementsummaryreportsIdEndpoint: The initialized CompanyCompaniesIdManagementsummaryreportsIdEndpoint object.
        """
        child = CompanyCompaniesIdManagementsummaryreportsIdEndpoint(self.client, parent_endpoint=self)
        child._id = id
        return child

    def paginated(
        self, page: int, page_size: int, params: ConnectWiseManageRequestParams | None = None
    ) -> PaginatedResponse[CompanyManagementSummary]:
        """
        Performs a GET request against the /company/companies/{id}/managementSummaryReports endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[CompanyManagementSummary]: The initialized PaginatedResponse object.
        """
        if params:
            params["page"] = page
            params["pageSize"] = page_size
        else:
            params = {"page": page, "pageSize": page_size}
        return PaginatedResponse(
            super()._make_request("GET", params=params), CompanyManagementSummary, self, page, page_size, params
        )

    def get(
        self, data: JSON | None = None, params: ConnectWiseManageRequestParams | None = None
    ) -> list[CompanyManagementSummary]:
        """
        Performs a GET request against the /company/companies/{id}/managementSummaryReports endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[CompanyManagementSummary]: The parsed response data.
        """
        return self._parse_many(CompanyManagementSummary, super()._make_request("GET", data=data, params=params).json())

    def post(
        self, data: JSON | None = None, params: ConnectWiseManageRequestParams | None = None
    ) -> CompanyManagementSummary:
        """
        Performs a POST request against the /company/companies/{id}/managementSummaryReports endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            CompanyManagementSummary: The parsed response data.
        """
        return self._parse_one(CompanyManagementSummary, super()._make_request("POST", data=data, params=params).json())

==> pyconnectwise-0.5.1.tar.gz: pyconnectwise-0.5.1/src/pyconnectwise/endpoints/manage/CompanyCompaniesIdManagementsummaryreportsEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.CompanyCompaniesIdManagementsummaryreportsCountEndpoint import \
    CompanyCompaniesIdManagementsummaryreportsCountEndpoint
from pyconnectwise.endpoints.manage.CompanyCompaniesIdManagementsummaryreportsIdEndpoint import \
    CompanyCompaniesIdManagementsummaryreportsIdEndpoint
from pyconnectwise.interfaces import IDeleteable, IGettable, IPaginateable, IPatchable, IPostable, IPuttable
from pyconnectwise.models.manage import CompanyManagementSummary
from pyconnectwise.responses.paginated_response import PaginatedResponse
from pyconnectwise.types import JSON, ConnectWiseAutomateRequestParams, ConnectWiseManageRequestParams, PatchRequestData


class CompanyCompaniesIdManagementsummaryreportsEndpoint(
    ConnectWiseEndpoint,
    IGettable[list[CompanyManagementSummary], ConnectWiseManageRequestParams],
    IPostable[CompanyManagementSummary, ConnectWiseManageRequestParams],
    IPaginateable[CompanyManagementSummary, ConnectWiseManageRequestParams],
):
    def __init__(self, client, parent_endpoint=None):
        ConnectWiseEndpoint.__init__(self, client, "managementSummaryReports", parent_endpoint=parent_endpoint)
        IGettable.__init__(self, list[CompanyManagementSummary])
        IPostable.__init__(self, CompanyManagementSummary)
        IPaginateable.__init__(self, CompanyManagementSummary)

        self.count = self._register_child_endpoint(
            CompanyCompaniesIdManagementsummaryreportsCountEndpoint(client, parent_endpoint=self)
        )

    def id(self, id: int) -> CompanyCompaniesIdManagementsummaryreportsIdEndpoint:
        """
        Sets the ID for this endpoint and returns an initialized CompanyCompaniesIdManagementsummaryreportsIdEndpoint object to move down the chain.

        Parameters:
            id (int): The ID to set.
        Returns:
            CompanyCompaniesIdManagementsummaryreportsIdEndpoint: The initialized CompanyCompaniesIdManagementsummaryreportsIdEndpoint object.
        """
        child = CompanyCompaniesIdManagementsummaryreportsIdEndpoint(self.client, parent_endpoint=self)
        child._id = id
        return child

    def paginated(
        self, page: int, page_size: int, params: ConnectWiseManageRequestParams | None = None
    ) -> PaginatedResponse[CompanyManagementSummary]:
        """
        Performs a GET request against the /company/companies/{id}/managementSummaryReports endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[CompanyManagementSummary]: The initialized PaginatedResponse object.
        """
        if params:
            params["page"] = page
            params["pageSize"] = page_size
        else:
            params = {"page": page, "pageSize": page_size}
        return PaginatedResponse(
            super()._make_request("GET", params=params), CompanyManagementSummary, self, page, page_size, params
        )

    def get(
        self, data: JSON | None = None, params: ConnectWiseManageRequestParams | None = None
    ) -> list[CompanyManagementSummary]:
        """
        Performs a GET request against the /company/companies/{id}/managementSummaryReports endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[CompanyManagementSummary]: The parsed response data.
        """
        return self._parse_many(CompanyManagementSummary, super()._make_request("GET", data=data, params=params).json())

    def post(
        self, data: JSON | None = None, params: ConnectWiseManageRequestParams | None = None
    ) -> CompanyManagementSummary:
        """
        Performs a POST request against the /company/companies/{id}/managementSummaryReports endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            CompanyManagementSummary: The parsed response data.
        """
        return self._parse_one(CompanyManagementSummary, super()._make_request("POST", data=data, params=params).json())
